pub fn diff_manifests(
local: &SyncManifest,
remote: &SyncManifest,
) -> Vec<SyncRange>Expand description
Compute the ranges the local side has that the remote side lacks.
pub fn diff_manifests(
local: &SyncManifest,
remote: &SyncManifest,
) -> Vec<SyncRange>Compute the ranges the local side has that the remote side lacks.